@@ -1,4 +1,4 @@
-import base64, string
+import base64, sys
 
 stSpam, stHam, stDump = 0, 1, 2
 
@@ -9,7 +9,7 @@ def readPemFromFile(fileObj, startMarker='-----BEGIN CERTIFICATE-----',
         certLine = fileObj.readline()
         if not certLine:
             break
-        certLine = string.strip(certLine)
+        certLine = certLine.strip()
         if state == stSpam:
             if certLine == startMarker:
                 certLines = []
@@ -23,5 +23,12 @@ def readPemFromFile(fileObj, startMarker='-----BEGIN CERTIFICATE-----',
         if state == stDump:
             substrate = ''
             for certLine in certLines:
-                substrate = substrate + base64.decodestring(certLine)
+                if sys.version_info[0] <= 2:
+                    substrate = substrate + base64.decodestring(certLine)
+                else:
+                    if not substrate:
+                        substrate = substrate.encode()
+                    substrate = substrate + base64.decodebytes(
+                        certLine.encode()
+                        )
             return substrate
