@@ -4,8 +4,8 @@ from pyasn1_modules import rfc1157
 import sys, socket
 
 if len(sys.argv) != 4:
-    print """Usage:
-$ %s <community> <host> <OID>""" % sys.argv[0]
+    print("""Usage:
+$ %s <community> <host> <OID>""" % sys.argv[0])
     sys.exit(-1)
 
 msg = rfc1157.Message()
@@ -22,7 +22,7 @@ vb = vbl.setComponentByPosition(0).getComponentByPosition(0)
 vb.setComponentByPosition(0, sys.argv[3])
 v = vb.setComponentByPosition(1).getComponentByPosition(1).setComponentByPosition(0).getComponentByPosition(0).setComponentByPosition(3).getComponentByPosition(3)
 
-print 'sending', msg.prettyPrint()
+print('sending: %s' % msg.prettyPrint())
 
 sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
 sock.sendto(encoder.encode(msg), (sys.argv[2], 161))
@@ -31,4 +31,4 @@ substrate, _ = sock.recvfrom(2048)
 
 rMsg, _ = decoder.decode(substrate, asn1Spec=msg)
 
-print 'received', rMsg.prettyPrint()
+print('received: %s' % rMsg.prettyPrint())
